#!/bin/bash


meFirmwareFile="11.21.51.1458.bin"
meFirmwareLocation="/ME-Flash/"
fwUpdLcl="FWUpdLcl"
fwUpdLclLocation=""
fwUpdLclLocation64="/ME-Flash/LINUX64/"
fwUpdLclLocation32="/ME-Flash/LINUX32/"
instructionsFile="README.txt"

answer="x"
output="nothing"

echo
echo "Updating Management Engine firmware will require a reboot in order for the update to be effective."
echo

while [ "$answer" = "x" ]; do
	read -p "Do you want to update the Management Engine firmware now [Y/N]? " yn
	case $yn in
		[Yy] ) answer="y";;
		[Nn] ) answer="n";;
		*) echo "Please answer [Y]es or [N]o."; answer="x";;
	esac
done

echo

if [ "$answer" = "n" ]; then
	echo "Please refer to the $instructionsFile file (below) for instructions to manually update your Management Engine firmware"
	echo
	cat "./$instructionsFile"
	echo
	exit
fi

if [ "$answer" = "y" ]; then
	output=$(uname -m)
	if [ "$output" = "x86_64" ]; then
		fwUpdLclLocation=$fwUpdLclLocation64
	elif [ "$output" = "i686" ]; then
		fwUpdLclLocation=$fwUpdLclLocation32
	else
		echo "Cannot detect if this is a 32bit or 64bit operating system." 
		echo "Please refer to the $instructionsFile file (below) for instructions to manually update your Management Engine firmware."
		echo
		cat "./$instructionsFile"
		echo
		exit
	fi
	sudo chmod u+x .$fwUpdLclLocation$fwUpdLcl

	output=$(sudo .$fwUpdLclLocation$fwUpdLcl -fwver)
	if [[ $output == *"Error "* ]]; then
		echo $output
		echo Cannot retrieve current FW version
		echo Please confirm that you are on a supported platform, you have the latest ME software driver, Intel AMT is enabled, you are running with administrator priveledges and try again.
		echo If you are still having issues, then please contact HP Support.
		exit
	elif [[ $output == *"FW Version:"* ]]; then
		output=$(echo $output | cut -d':' -f 3)	
		output="${output:1:-5}"
	else
		echo Cannot retrieve current FW version
		output=${output#*"All rights reserved."}
		output="${output:6}"
		echo $output
		echo
		echo Please confirm that you, have the latest ME software driver, Intel AMT is enabled, you are running with administrator priveledges and try again.
		echo If you are still having issues, then please contact HP Support.
		exit
	fi	
	echo "Your current Management Engine Firmware version: $output"
	output="${meFirmwareFile:0:-4}"
	echo "Updating to version: $output"
	echo
	echo "Management Engine firmware update initiated."
	echo "This may take a couple minutes..."
	output=$(sudo .$fwUpdLclLocation$fwUpdLcl -f ".$meFirmwareLocation$meFirmwareFile")
	if [[ $output == *"FW Update is complete"* ]]; then
		echo
		echo "Update complete. You must reboot your computer in order for the Management Engine firmware update to be effective."
	elif [[ $output == *"Error 8703"* ]]; then
		echo
		echo "Update already completed.  You must reboot your computer in order for the Management Engine firmware update to be effective."
	elif [[ $output == *"Error 8716"* ]] || [[ $output == *"Error 8772"* ]]; then
		echo
		echo "Your system already has this firmware version installed."
		echo "If you would like to install this firmware again, run the appropriate command in README.txt, and add the -allowsv argument."
	else
		output=${output#*"Checking firmware parameters..."}
		output="${output:1}"
		echo
		echo "The installation failed"
		echo "$output"
		echo "Please confirm that you have the latest ME software driver, Intel AMT is enabled, you are running with administrator priveledges and try again."
		echo "If you are still having issues, then please contact HP Support."
	fi
	sudo chmod u-x .$fwUpdLclLocation$fwUpdLcl
	echo
	echo
fi
